==> sems-0.8.12.tar.gz: sems-0.8.12/plug-in/isdngw/IsdnGatewayDialog.h <==
/*
 * $Id: IsdnGatewayDialog.h,v 1.2.2.2 2004/01/23 13:40:58 ullstar Exp $
 *
 * Copyright (C) 2003 Ulrich Abend
 *
 * This file is part of isdngw, a free isdn gateway plugin 
 * for sems, a free SIP media server.
 *
 * isdngw is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * For a license to use the ser software under conditions
 * other than those described here, or to purchase support for this
 * software, please contact iptel.org by e-mail at the following addresses:
 *    info@iptel.org
 *
 * isdngw is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _ISDNGATEWAYDIALOG_H_
#define _ISDNGATEWAYDIALOG_H_

#include "AmApi.h"
#include "IsdnCall.h"
#include "IsdnCallManager.h"

/** A SIP <-> PSTN voice connection. Instances of this class are returned 
 * by IsdnGatewayFactory on successfull call setup. sems then calls 
 * onSessionStart and onBye. */
class IsdnGatewayDialog : public AmDialogState
{
private:
	IsdnCall* m_call;
	
public:
  IsdnGatewayDialog(IsdnCall *call);
  ~IsdnGatewayDialog();
  void onSessionStart(AmRequest* req);
  void onBye(AmRequest* req);
  void onError(unsigned int code, const string& reason);
  void onBeforeCallAccept(AmRequest* req);
	int onOther(AmSessionEvent* event);
};

#endif

==> sems_2004_01_04.tar.gz: sems_2004_01_04/plug-in/isdngw/IsdnGatewayDialog.h <==
/*
 * $Id: IsdnGatewayDialog.h,v 1.2 2003/11/16 19:28:59 ullstar Exp $
 *
 * Copyright (C) 2003 Ulrich Abend
 *
 * This file is part of isdngw, a free isdn gateway plugin 
 * for sems, a free SIP media server.
 *
 * isdngw is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * For a license to use the ser software under conditions
 * other than those described here, or to purchase support for this
 * software, please contact iptel.org by e-mail at the following addresses:
 *    info@iptel.org
 *
 * isdngw is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _ISDNGATEWAYDIALOG_H_
#define _ISDNGATEWAYDIALOG_H_

#include "AmApi.h"
#ifdef USE_CAPI20
#include "IsdnCapiConnection.h"
#endif

#define CONNECTIONTYPE_I4L 0
#define CONNECTIONTYPE_CAPI 1

/** A SIP <-> PSTN voice connection. Instances of this class are returned 
 * by IsdnGatewayFactory on successfull call setup. sems then calls 
 * onSessionStart and onBye. */
class IsdnGatewayDialog : public AmDialogState
{
private:
	class IsdnDevice *m_idev;
	int m_controller;
	int m_connectiontype;
	#ifdef USE_CAPI20
  class IsdnCapiConnection *m_ccon;
	#endif

public:
  IsdnGatewayDialog(IsdnDevice *idev);
	#ifdef USE_CAPI20
  IsdnGatewayDialog(int controller);
	#endif
  ~IsdnGatewayDialog();
  void onSessionStart(AmRequest* req);
  void hup(AmRequest* req);
  void onBye(AmRequest* req);
  void onError(unsigned int code, const string& reason);
  void onBeforeCallAccept(AmRequest* req);
	int onOther(AmSessionEvent* event);
			
};

#endif
